@@ -1,6 +1,13 @@
-/* demo/misc1/randlib/rand01.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20050501).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -27,7 +34,7 @@ static integer c__4 = 4;
     static integer i__;
     static real x, y;
     static integer nn;
-    extern doublereal rngu0_(integer *);
+    extern real rngu0_(integer *);
     static integer iseed;
 
     /* Fortran I/O blocks */
