@@ -1,6 +1,13 @@
-/* src/grph2/umpack/umbndp.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20050501).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -42,10 +49,10 @@ static integer c__1 = 1;
     for (i__ = 1; i__ <= i__1; ++i__) {
 	umqpnt_(&i__, &uxz, &uyz);
 	stftrf_(&uxz, &uyz, &vx, &vy);
-	*vxmin = dmin(*vxmin,vx);
-	*vxmax = dmax(*vxmax,vx);
-	*vymin = dmin(*vymin,vy);
-	*vymax = dmax(*vymax,vy);
+	*vxmin = min(*vxmin,vx);
+	*vxmax = max(*vxmax,vx);
+	*vymin = min(*vymin,vy);
+	*vymax = max(*vymax,vy);
 /* L40: */
     }
     return 0;
