@@ -1,6 +1,13 @@
-/* src/math1/lrllib/lrne1.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20050501).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -28,7 +35,7 @@ logical lrne1_(real *x, real *y)
     }
     glrget_("RFACT", &rfact, (ftnlen)5);
     ep = repsl * rfact;
-    ret_val = (r__1 = *x - *y, dabs(r__1)) > (dabs(*x) + dabs(*y)) * ep / 2;
+    ret_val = (r__1 = *x - *y, abs(r__1)) > (abs(*x) + abs(*y)) * ep / 2;
     return ret_val;
 } /* lrne1_ */
 
