@@ -1,6 +1,13 @@
-/* src/math1/maplib/mpznwt.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20050501).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -20,12 +27,12 @@
 
     for (i__ = 1; i__ <= 20; ++i__) {
 	(*func)(phi, alpha, &f, &df);
-	if (dabs(df) < 1e-5f) {
+	if (abs(df) < 1.2e-5f) {
 	    return 0;
 	}
 	dx = f / df;
 	*alpha -= dx;
-	if (dabs(dx) < 1e-4f) {
+	if (abs(dx) < 1e-4f) {
 	    return 0;
 	}
 /* L10: */
