@@ -1,6 +1,13 @@
-/* src/math1/maplib/xmplon.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20050501).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -12,7 +19,7 @@ static real c_b2 = 1e-5f;
 /* ----------------------------------------------------------------------- */
 /*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-doublereal xmplon_(real *xlon)
+real xmplon_(real *xlon)
 {
     /* System generated locals */
     integer i__1, i__2;
@@ -26,11 +33,11 @@ doublereal xmplon_(real *xlon)
     static real pi;
     static integer ix, nx;
     static real rx;
-    extern doublereal rfpi_(void);
+    extern real rfpi_(void);
     extern logical lreqa_(real *, real *, real *);
 
     pi = rfpi_();
-    rx = dabs(*xlon) / pi;
+    rx = abs(*xlon) / pi;
     nx = i_nint(&rx);
     r__1 = (real) nx;
     if (lreqa_(&rx, &r__1, &c_b2)) {
