@@ -1,6 +1,13 @@
-/* src/math1/rfalib/rrms.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20050501).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -10,14 +17,14 @@
 /* ----------------------------------------------------------------------- */
 /*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-doublereal rrms_(real *rx, integer *n, integer *jx)
+real rrms_(real *rx, integer *n, integer *jx)
 {
     /* System generated locals */
     real ret_val;
 
     /* Local variables */
-    extern doublereal rrms0_(real *, integer *, integer *), rrms1_(real *, 
-	    integer *, integer *);
+    extern real rrms0_(real *, integer *, integer *), rrms1_(real *, integer *
+	    , integer *);
     static logical lmiss;
     extern /* Subroutine */ int gllget_(char *, logical *, ftnlen);
 
