@@ -1,6 +1,13 @@
-/* src/math1/rfblib/rcov.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20050501).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -10,7 +17,7 @@
 /* ----------------------------------------------------------------------- */
 /*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-doublereal rcov_(real *rx, real *ry, integer *n, integer *jx, integer *jy)
+real rcov_(real *rx, real *ry, integer *n, integer *jx, integer *jy)
 {
     /* System generated locals */
     integer i__1;
@@ -19,7 +26,7 @@ doublereal rcov_(real *rx, real *ry, integer *n, integer *jx, integer *jy)
     /* Local variables */
     static integer i__, kx, ky;
     static real sum, xave, yave;
-    extern doublereal rave0_(real *, integer *, integer *);
+    extern real rave0_(real *, integer *, integer *);
 
     /* Parameter adjustments */
     --ry;
